@@ -2,35 +2,72 @@
 
 """This module contains output functions to BEL scripts."""
 
+import gzip
 import itertools as itt
 import logging
 import time
-from typing import Iterable, List, Mapping, Optional, TextIO, Tuple
+from typing import Iterable, List, Mapping, Optional, TextIO, Tuple, Union
+
+from networkx.utils import open_file
 
 import bel_resources.constants
 from bel_resources import make_knowledge_header
 from .constants import (
-    ACTIVITY, ANNOTATIONS, BEL_DEFAULT_NAMESPACE, CITATION, CITATION_REFERENCE, CITATION_TYPE, COMPLEX, COMPOSITE,
-    DEGRADATION, EFFECT, EVIDENCE, FROM_LOC, FUNCTION, FUSION, GOCC_KEYWORD, GOCC_LATEST, IDENTIFIER, LOCATION,
-    MODIFIER, NAME, NAMESPACE, OBJECT, PYBEL_AUTOEVIDENCE, REACTION, RELATION, SUBJECT, TO_LOC, TRANSLOCATION,
-    UNQUALIFIED_EDGES, VARIANTS, VERSION,
+    ACTIVITY, ANNOTATIONS, BEL_DEFAULT_NAMESPACE, CELL_SURFACE, CITATION, CITATION_DB, CITATION_IDENTIFIER,
+    CITATION_TYPE_PUBMED, DEGRADATION, EFFECT, EVIDENCE, EXTRACELLULAR, FROM_LOC, INTRACELLULAR, LOCATION, MODIFIER,
+    NAME, NAMESPACE, OBJECT, PYBEL_AUTOEVIDENCE, PYBEL_PUBMED, RELATION, SET_CITATION_FMT, SUBJECT, TO_LOC,
+    TRANSLOCATION, UNQUALIFIED_EDGES, VARIANTS,
 )
-from .dsl import BaseEntity
+from .dsl import BaseAbundance, BaseEntity, FusionBase, ListAbundance, Reaction
 from .typing import EdgeData
 from .utils import ensure_quotes
+from .version import VERSION
 
 __all__ = [
-    'to_bel_lines',
-    'to_bel',
-    'to_bel_path',
+    'to_bel_script',
+    'to_bel_script_gz',
+    'to_bel_script_lines',
     'edge_to_bel',
+    'edge_to_tuple',
+    'calculate_canonical_name',
 ]
 
-log = logging.getLogger(__name__)
+logger = logging.getLogger(__name__)
 
 EdgeTuple = Tuple[BaseEntity, BaseEntity, str, EdgeData]
 
 
+@open_file(1, mode='w')
+def to_bel_script(graph, path: Union[str, TextIO], use_identifiers: bool = True) -> None:
+    """Write the BELGraph as a canonical BEL script.
+
+    :param BELGraph graph: the BEL Graph to output as a BEL Script
+    :param path: A path or file-like.
+    :param use_identifiers: Enables extended `BEP-0008 <http://bep.bel.bio/published/BEP-0008.html>`_ syntax
+    """
+    for line in to_bel_script_lines(graph, use_identifiers=use_identifiers):
+        print(line, file=path)
+
+
+def to_bel_script_gz(graph, path, **kwargs) -> None:
+    """Write the graph as a BEL Script a gzip file."""
+    with gzip.open(path, 'wt') as file:
+        to_bel_script(graph, file, **kwargs)
+
+
+def to_bel_script_lines(graph, use_identifiers: bool = False) -> Iterable[str]:
+    """Iterate over the lines of the BEL graph as a canonical BEL script.
+
+    :param pybel.BELGraph graph: A BEL Graph
+    :param use_identifiers: Enables extended `BEP-0008 <http://bep.bel.bio/published/BEP-0008.html>`_ syntax
+    """
+    return itt.chain(
+        _to_bel_lines_header(graph),
+        _to_bel_lines_body(graph, use_identifiers=use_identifiers),
+        _to_bel_lines_footer(graph, use_identifiers=use_identifiers),
+    )
+
+
 def postpend_location(bel_string: str, location_model) -> str:
     """Rip off the closing parentheses and adds canonicalized modification.
 
@@ -47,18 +84,25 @@ def postpend_location(bel_string: str, location_model) -> str:
     return "{}, loc({}:{}))".format(
         bel_string[:-1],
         location_model[NAMESPACE],
-        ensure_quotes(location_model[NAME])
+        ensure_quotes(location_model[NAME]),
     )
 
 
-def _decanonicalize_edge_node(node: BaseEntity, edge_data: EdgeData, node_position: str) -> str:
+def _decanonicalize_edge_node(
+    node: BaseEntity,
+    edge_data: EdgeData,
+    node_position: str,
+    *,
+    use_identifiers: bool = False
+) -> str:
     """Canonicalize a node with its modifiers stored in the given edge to a BEL string.
 
     :param node: A PyBEL node data dictionary
     :param edge_data: A PyBEL edge data dictionary
     :param node_position: Either :data:`pybel.constants.SUBJECT` or :data:`pybel.constants.OBJECT`
+    :param use_identifiers: Enables extended `BEP-0008 <http://bep.bel.bio/published/BEP-0008.html>`_ syntax
     """
-    node_str = node.as_bel()
+    node_str = node.as_bel(use_identifiers=use_identifiers)
 
     if node_position not in edge_data:
         return node_str
@@ -94,42 +138,70 @@ def _decanonicalize_edge_node(node: BaseEntity, edge_data: EdgeData, node_positi
         to_loc_data = effect[TO_LOC]
         from_loc_data = effect[FROM_LOC]
 
-        from_loc = "fromLoc({}:{})".format(
-            from_loc_data[NAMESPACE],
-            ensure_quotes(from_loc_data[NAME])
-        )
+        if from_loc_data[NAMESPACE] == BEL_DEFAULT_NAMESPACE and from_loc_data[NAME] == INTRACELLULAR:
+            if to_loc_data[NAMESPACE] == BEL_DEFAULT_NAMESPACE and to_loc_data[NAME] == EXTRACELLULAR:
+                return 'sec({})'.format(node_str)
+            if to_loc_data[NAMESPACE] == BEL_DEFAULT_NAMESPACE and to_loc_data[NAME] == CELL_SURFACE:
+                return 'surf({})'.format(node_str)
 
-        to_loc = "toLoc({}:{})".format(
-            to_loc_data[NAMESPACE],
-            ensure_quotes(to_loc_data[NAME])
-        )
+        from_loc = _get_tloc_terminal('fromLoc', from_loc_data)
+        to_loc = _get_tloc_terminal('toLoc', to_loc_data)
 
         return "tloc({}, {}, {})".format(node_str, from_loc, to_loc)
 
     raise ValueError('invalid modifier: {}'.format(modifier))
 
 
-def edge_to_bel(u: BaseEntity, v: BaseEntity, data: EdgeData, sep: Optional[str] = None) -> str:
+def _get_tloc_terminal(side, data):
+    return "{}({}:{})".format(
+        side,
+        data[NAMESPACE],
+        ensure_quotes(data[NAME]),
+    )
+
+
+def edge_to_tuple(
+    u: BaseEntity,
+    v: BaseEntity,
+    data: EdgeData,
+    use_identifiers: bool = False,
+) -> Tuple[str, str, str]:
+    """Take two nodes and gives back a BEL string representing the statement.
+
+    :param u: The edge's source's PyBEL node data dictionary
+    :param v: The edge's target's PyBEL node data dictionary
+    :param data: The edge's data dictionary
+    :param use_identifiers: Enables extended `BEP-0008 <http://bep.bel.bio/published/BEP-0008.html>`_ syntax
+    """
+    u_str = _decanonicalize_edge_node(u, data, node_position=SUBJECT, use_identifiers=use_identifiers)
+    v_str = _decanonicalize_edge_node(v, data, node_position=OBJECT, use_identifiers=use_identifiers)
+    return u_str, data[RELATION], v_str
+
+
+def edge_to_bel(
+    u: BaseEntity,
+    v: BaseEntity,
+    data: EdgeData,
+    sep: Optional[str] = None,
+    use_identifiers: bool = False,
+) -> str:
     """Take two nodes and gives back a BEL string representing the statement.
 
     :param u: The edge's source's PyBEL node data dictionary
     :param v: The edge's target's PyBEL node data dictionary
     :param data: The edge's data dictionary
     :param sep: The separator between the source, relation, and target. Defaults to ' '
+    :param use_identifiers: Enables extended `BEP-0008 <http://bep.bel.bio/published/BEP-0008.html>`_ syntax
     """
     sep = sep or ' '
-    u_str = _decanonicalize_edge_node(u, data, node_position=SUBJECT)
-    v_str = _decanonicalize_edge_node(v, data, node_position=OBJECT)
-
-    return sep.join((u_str, data[RELATION], v_str))
+    return sep.join(edge_to_tuple(u=u, v=v, data=data, use_identifiers=use_identifiers))
 
 
-def _sort_qualified_edges_helper(edge_tuple):
-    u, v, k, d = edge_tuple
+def _sort_qualified_edges_helper(t: EdgeTuple) -> Tuple[str, str, str]:
     return (
-        d[CITATION][CITATION_TYPE],
-        d[CITATION][CITATION_REFERENCE],
-        d[EVIDENCE],
+        t[3][CITATION][CITATION_DB],
+        t[3][CITATION][CITATION_IDENTIFIER],
+        t[3][EVIDENCE],
     )
 
 
@@ -146,9 +218,9 @@ def sort_qualified_edges(graph) -> Iterable[EdgeTuple]:
     return sorted(qualified_edges, key=_sort_qualified_edges_helper)
 
 
-def _citation_sort_key(t: EdgeTuple) -> str:
+def _citation_sort_key(t: EdgeTuple) -> Tuple[str, str]:
     """Make a confusing 4 tuple sortable by citation."""
-    return '"{}", "{}"'.format(t[3][CITATION][CITATION_TYPE], t[3][CITATION][CITATION_REFERENCE])
+    return t[3][CITATION][CITATION_DB], t[3][CITATION][CITATION_IDENTIFIER]
 
 
 def _evidence_sort_key(t: EdgeTuple) -> str:
@@ -181,11 +253,8 @@ def _to_bel_lines_header(graph) -> Iterable[str]:
 
     :param pybel.BELGraph graph: A BEL graph
     """
-    if GOCC_KEYWORD not in graph.namespace_url:
-        graph.namespace_url[GOCC_KEYWORD] = GOCC_LATEST
-
     yield '# This document was created by PyBEL v{} and bel-resources v{} on {}\n'.format(
-        VERSION, bel_resources.constants.VERSION, time.asctime()
+        VERSION, bel_resources.constants.VERSION, time.asctime(),
     )
     yield from make_knowledge_header(
         namespace_url=graph.namespace_url,
@@ -193,11 +262,11 @@ def _to_bel_lines_header(graph) -> Iterable[str]:
         annotation_url=graph.annotation_url,
         annotation_patterns=graph.annotation_pattern,
         annotation_list=graph.annotation_list,
-        **graph.document
+        **graph.document,
     )
 
 
-def group_citation_edges(edges: Iterable[EdgeTuple]) -> Iterable[Tuple[str, Iterable[EdgeTuple]]]:
+def group_citation_edges(edges: Iterable[EdgeTuple]) -> Iterable[Tuple[Tuple[str, str], Iterable[EdgeTuple]]]:
     """Return an iterator over pairs of citation values and their corresponding edge iterators."""
     return itt.groupby(edges, key=_citation_sort_key)
 
@@ -207,15 +276,16 @@ def group_evidence_edges(edges: Iterable[EdgeTuple]) -> Iterable[Tuple[str, Iter
     return itt.groupby(edges, key=_evidence_sort_key)
 
 
-def _to_bel_lines_body(graph) -> Iterable[str]:
+def _to_bel_lines_body(graph, use_identifiers: bool = False) -> Iterable[str]:
     """Iterate the lines of a BEL graph's corresponding BEL script's body.
 
     :param pybel.BELGraph graph: A BEL graph
+    :param use_identifiers: Enables extended `BEP-0008 <http://bep.bel.bio/published/BEP-0008.html>`_ syntax
     """
     qualified_edges = sort_qualified_edges(graph)
 
-    for citation, citation_edges in group_citation_edges(qualified_edges):
-        yield 'SET Citation = {{{}}}\n'.format(citation)
+    for (citation_db, citation_id), citation_edges in group_citation_edges(qualified_edges):
+        yield SET_CITATION_FMT.format(citation_db, citation_id) + '\n'
 
         for evidence, evidence_edges in group_evidence_edges(citation_edges):
             yield 'SET SupportingText = "{}"'.format(evidence)
@@ -227,7 +297,7 @@ def _to_bel_lines_body(graph) -> Iterable[str]:
                 for key in keys:
                     yield _set_annotation_to_str(annotations_data, key)
 
-                yield graph.edge_to_bel(u, v, data)
+                yield graph.edge_to_bel(u, v, data, use_identifiers=use_identifiers)
 
                 if keys:
                     yield _unset_annotation_to_str(keys)
@@ -237,10 +307,11 @@ def _to_bel_lines_body(graph) -> Iterable[str]:
         yield '#' * 80
 
 
-def _to_bel_lines_footer(graph) -> Iterable[str]:
+def _to_bel_lines_footer(graph, use_identifiers: bool = False) -> Iterable[str]:
     """Iterate the lines of a BEL graph's corresponding BEL script's footer.
 
     :param pybel.BELGraph graph: A BEL graph
+    :param use_identifiers: Enables extended `BEP-0008 <http://bep.bel.bio/published/BEP-0008.html>`_ syntax
     """
     unqualified_edges_to_serialize = [
         (u, v, d)
@@ -256,76 +327,38 @@ def _to_bel_lines_footer(graph) -> Iterable[str]:
 
     if unqualified_edges_to_serialize or isolated_nodes_to_serialize:
         yield '###############################################\n'
-        yield 'SET Citation = {"PubMed","Added by PyBEL","29048466"}'
+        yield SET_CITATION_FMT.format(CITATION_TYPE_PUBMED, PYBEL_PUBMED)
         yield 'SET SupportingText = "{}"'.format(PYBEL_AUTOEVIDENCE)
 
         for u, v, data in unqualified_edges_to_serialize:
-            yield '{} {} {}'.format(u.as_bel(), data[RELATION], v.as_bel())
+            yield '{} {} {}'.format(
+                u.as_bel(use_identifiers=use_identifiers),
+                data[RELATION],
+                v.as_bel(use_identifiers=use_identifiers),
+            )
 
         for node in isolated_nodes_to_serialize:
-            yield node.as_bel()
+            yield node.as_bel(use_identifiers=use_identifiers)
 
         yield 'UNSET SupportingText'
         yield 'UNSET Citation'
 
 
-def to_bel_lines(graph) -> Iterable[str]:
-    """Iterate over the lines of the BEL graph as a canonical BEL Script (.bel).
-
-    :param pybel.BELGraph graph: the BEL Graph to output as a BEL Script
-    """
-    return itt.chain(
-        _to_bel_lines_header(graph),
-        _to_bel_lines_body(graph),
-        _to_bel_lines_footer(graph),
-    )
-
-
-def to_bel(graph, file: Optional[TextIO] = None) -> None:
-    """Output the BEL graph as canonical BEL to the given file/file-like/stream.
-
-    :param BELGraph graph: the BEL Graph to output as a BEL Script
-    :param file: A writable file-like object. If None, defaults to standard out.
-    """
-    for line in to_bel_lines(graph):
-        print(line, file=file)
-
-
-def to_bel_path(graph, path: str, mode: str = 'w', **kwargs) -> None:
-    """Write the BEL graph as a canonical BEL Script to the given path.
-
-    :param BELGraph graph: the BEL Graph to output as a BEL Script
-    :param path: A file path
-    :param mode: The file opening mode. Defaults to 'w'
-    """
-    with open(path, mode=mode, **kwargs) as bel_file:
-        to_bel(graph, bel_file)
-
-
-def calculate_canonical_name(data: BaseEntity) -> str:
+def calculate_canonical_name(node: BaseEntity, use_identifiers: bool = True) -> str:
     """Calculate the canonical name for a given node.
 
     If it is a simple node, uses the already given name. Otherwise, it uses the BEL string.
     """
-    if data[FUNCTION] == COMPLEX and NAMESPACE in data:
-        return data[NAME]
+    if isinstance(node, (Reaction, ListAbundance, FusionBase)):
+        return node.as_bel(use_identifiers=True)
 
-    if VARIANTS in data:
-        return data.as_bel()
+    elif isinstance(node, BaseAbundance):
+        if VARIANTS in node:
+            return node.as_bel(use_identifiers=True)
+        elif use_identifiers and node.entity.identifier and node.entity.name:
+            return node.obo
+        else:
+            return node.curie
 
-    if FUSION in data:
-        return data.as_bel()
-
-    if data[FUNCTION] in {REACTION, COMPOSITE, COMPLEX}:
-        return data.as_bel()
-
-    if VARIANTS not in data and FUSION not in data:  # this is should be a simple node
-        if IDENTIFIER in data and NAME in data:
-            return '{namespace}:{identifier} ({name})'.format(**data)
-
-        if IDENTIFIER in data:
-            return '{namespace}:{identifier}'.format(namespace=data[NAMESPACE], identifier=data[IDENTIFIER])
-
-        return data[NAME]
-
-    raise ValueError('Unexpected node data: {}'.format(data))
+    else:
+        raise TypeError('Unhandled node: {}'.format(node))
