@@ -3,100 +3,12 @@
 """Constants for PyBEL.
 
 This module maintains the strings used throughout the PyBEL codebase to promote consistency.
-
-Configuration Loading
----------------------
-By default, PyBEL loads its configuration from ``~/.config/pybel/config.json``. This json is stored in the object
-:data:`pybel.constants.config`.
 """
 
-from json import load
-from logging import getLogger
-from os import environ, makedirs, mkdir, path
-
-log = getLogger(__name__)
-
-VERSION = '0.13.1'
-
-#: The last PyBEL version where the graph data definition changed
-PYBEL_MINIMUM_IMPORT_VERSION = 0, 13, 0
-
-BELFRAMEWORK_DOMAIN = 'http://resource.belframework.org'
-OPENBEL_DOMAIN = 'http://resources.openbel.org'
-
-SMALL_CORPUS_URL = OPENBEL_DOMAIN + '/belframework/20150611/knowledge/small_corpus.bel'
-LARGE_CORPUS_URL = OPENBEL_DOMAIN + '/belframework/20150611/knowledge/large_corpus.bel'
-
-FRAUNHOFER_RESOURCES = 'https://owncloud.scai.fraunhofer.de/index.php/s/JsfpQvkdx3Y5EMx/download?path='
-OPENBEL_NAMESPACE_RESOURCES = OPENBEL_DOMAIN + '/belframework/20150611/namespace/'
-OPENBEL_ANNOTATION_RESOURCES = OPENBEL_DOMAIN + '/belframework/20150611/annotation/'
-
-#: GOCC is the only namespace that needs to be stored because translocations use some of its values by default
-GOCC_LATEST = 'https://arty.scai.fraunhofer.de/artifactory/bel/namespace/go-cellular-component/go-cellular-component-20170511.belns'
-GOCC_KEYWORD = 'GOCC'
-
-#: The environment variable that contains the default SQL connection information for the PyBEL cache
-PYBEL_CONNECTION = 'PYBEL_CONNECTION'
-
-#: The default directory where PyBEL files, including logs and the  default cache, are stored. Created if not exists.
-PYBEL_DIR = environ.get('PYBEL_RESOURCE_DIRECTORY', path.join(path.expanduser('~'), '.pybel'))
-if not path.exists(PYBEL_DIR):
-    try:
-        mkdir(PYBEL_DIR)
-    except FileExistsError:
-        log.debug('pybel data directory was created already: %s', PYBEL_DIR)
-
-DEFAULT_CACHE_NAME = 'pybel_{}.{}.{}_cache.db'.format(*PYBEL_MINIMUM_IMPORT_VERSION)
-#: The default cache location is ``~/.pybel/data/pybel_cache.db``
-DEFAULT_CACHE_LOCATION = path.join(PYBEL_DIR, DEFAULT_CACHE_NAME)
-#: The default cache connection string uses sqlite.
-DEFAULT_CACHE_CONNECTION = 'sqlite:///' + DEFAULT_CACHE_LOCATION
-
-_BASE_CONFIG_DIR = path.join(path.expanduser('~'), '.config')
+from .config import connection
 
 
-def get_config_dir():
-    """Return the path to the directory where configuration is stored for PyBEL.
-
-     Can be overridden by setting the environment variable ``PYBEL_CONFIG_DIRECTORY``.
-
-    :rtype: str
-    """
-    if VERSION.endswith('-dev'):
-        return environ.get('PYBEL_DEV_CONFIG_DIRECTORY', path.join(_BASE_CONFIG_DIR, 'pybel-dev'))
-    return environ.get('PYBEL_CONFIG_DIRECTORY', path.join(_BASE_CONFIG_DIR, 'pybel'))
-
-
-_config_dir = get_config_dir()
-if not path.exists(_config_dir):
-    try:
-        makedirs(_config_dir)
-    except FileExistsError:
-        log.debug('config folder was already created: %s', _config_dir)
-
-#: The global configuration for PyBEL is stored here. By default, it loads from ``~/.config/pybel/config.json``
-config = {
-    PYBEL_CONNECTION: DEFAULT_CACHE_CONNECTION
-}
-
-
-def get_config_path():
-    """Return the path of the configuration file.
-
-    By default, should just be a file called ``config.json`` inside the directory returned by :func:`get_config_dir`.
-
-    :rtype: str
-    """
-    return path.join(_config_dir, 'config.json')
-
-
-_config_path = get_config_path()
-if path.exists(_config_path):
-    with open(_config_path) as f:
-        config.update(load(f))
-
-
-def get_cache_connection():
+def get_cache_connection() -> str:
     """Get the preferred RFC-1738 database connection string.
 
     1. Check the environment variable ``PYBEL_CONNECTION``
@@ -104,21 +16,8 @@ def get_cache_connection():
        file might be in a different place if the environment variable ``PYBEL_CONFIG_DIRECTORY`` has been set.
     3. Return a default connection string using a SQLite database in the ``~/.pybel``. Optionally, this directory
        might be in a different place if the environment variable ``PYBEL_RESOURCE_DIRECTORY`` has been set.
-
-    :rtype: str
     """
-    connection = environ.get(PYBEL_CONNECTION)
-    if connection is not None:
-        log.info('getting environment-defined connection: %s', connection)
-        return connection
-
-    connection = config.get(PYBEL_CONNECTION)
-    if connection is not None:
-        log.info('getting configured connection %s', connection)
-        return connection
-
-    log.debug('using default connection %s', DEFAULT_CACHE_CONNECTION)
-    return DEFAULT_CACHE_CONNECTION
+    return connection
 
 
 PYBEL_CONTEXT_TAG = 'pybel_context'
@@ -138,14 +37,14 @@ CITATION_TYPE_OTHER = 'Other'
 #: The valid citation types
 #: .. seealso:: https://wiki.openbel.org/display/BELNA/Citation
 CITATION_TYPES = {
-    CITATION_TYPE_BOOK,
-    CITATION_TYPE_PUBMED,
-    CITATION_TYPE_PMC,
-    CITATION_TYPE_JOURNAL,
-    CITATION_TYPE_ONLINE,
-    CITATION_TYPE_URL,
-    CITATION_TYPE_DOI,
-    CITATION_TYPE_OTHER
+    CITATION_TYPE_BOOK: None,
+    CITATION_TYPE_PUBMED: 'pmid',
+    CITATION_TYPE_PMC: 'pmc',
+    CITATION_TYPE_JOURNAL: None,
+    CITATION_TYPE_ONLINE: None,
+    CITATION_TYPE_URL: None,
+    CITATION_TYPE_DOI: 'doi',
+    CITATION_TYPE_OTHER: None,
 }
 
 NAMESPACE_DOMAIN_BIOPROCESS = 'BiologicalProcess'
@@ -158,24 +57,22 @@ NAMESPACE_DOMAIN_TYPES = {
     NAMESPACE_DOMAIN_BIOPROCESS,
     NAMESPACE_DOMAIN_CHEMICAL,
     NAMESPACE_DOMAIN_GENE,
-    NAMESPACE_DOMAIN_OTHER
+    NAMESPACE_DOMAIN_OTHER,
 }
 
 #: Represents the key for the citation type in a citation dictionary
-CITATION_TYPE = 'type'
-#: Represents the key for the citation name in a citation dictionary
-CITATION_NAME = 'name'
+CITATION_DB = 'db'
 #: Represents the key for the citation reference in a citation dictionary
-CITATION_REFERENCE = 'reference'
+CITATION_IDENTIFIER = 'db_id'
+
+#: Represents the key for the optional PyBEL citation title entry in a citation dictionary
+CITATION_DB_NAME = 'db_name'
 #: Represents the key for the citation date in a citation dictionary
 CITATION_DATE = 'date'
 #: Represents the key for the citation authors in a citation dictionary
 CITATION_AUTHORS = 'authors'
 #: Represents the key for the citation comment in a citation dictionary
-CITATION_COMMENTS = 'comments'
-
-#: Represents the key for the optional PyBEL citation title entry in a citation dictionary
-CITATION_TITLE = 'title'
+CITATION_JOURNAL = 'db_name'
 #: Represents the key for the optional PyBEL citation volume entry in a citation dictionary
 CITATION_VOLUME = 'volume'
 #: Represents the key for the optional PyBEL citation issue entry in a citation dictionary
@@ -187,9 +84,6 @@ CITATION_FIRST_AUTHOR = 'first'
 #: Represents the key for the optional PyBEL citation last author entry in a citation dictionary
 CITATION_LAST_AUTHOR = 'last'
 
-#: Represents the ordering of the citation entries in a control statement (SET Citation = ...)
-CITATION_ENTRIES = CITATION_TYPE, CITATION_NAME, CITATION_REFERENCE, CITATION_DATE, CITATION_AUTHORS, CITATION_COMMENTS
-
 # Used during BEL parsing
 
 MODIFIER = 'modifier'
@@ -206,9 +100,15 @@ TRANSLOCATION = 'Translocation'
 CELL_SECRETION = 'CellSecretion'
 CELL_SURFACE_EXPRESSION = 'CellSurfaceExpression'
 
+INTRACELLULAR = 'intracellular'
+EXTRACELLULAR = 'extracellular space'
+CELL_SURFACE = 'cell surface'
+
 # Internal node data format keys
 #: The node data key specifying the node's function (e.g. :data:`GENE`, :data:`MIRNA`, :data:`BIOPROCESS`, etc.)
 FUNCTION = 'function'
+#: The key specifying a concept
+CONCEPT = 'concept'
 #: The key specifying an identifier dictionary's namespace. Used for nodes, activities, and transformations.
 NAMESPACE = 'namespace'
 #: The key specifying an identifier dictionary's name. Used for nodes, activities, and transformations.
@@ -219,6 +119,8 @@ IDENTIFIER = 'identifier'
 LABEL = 'label'
 #: The key specifying an optional description for the node
 DESCRIPTION = 'description'
+#: The key specifying xrefs
+XREFS = 'xref'
 
 #: They key representing the nodes that are a member of a composite or complex
 MEMBERS = 'members'
@@ -262,7 +164,7 @@ PYBEL_VARIANT_KINDS = {
     HGVS,
     PMOD,
     GMOD,
-    FRAGMENT
+    FRAGMENT,
 }
 
 #: The group of all BEL-provided keys for node data dictionaries, used for hashing.
@@ -303,6 +205,9 @@ BIOPROCESS = 'BiologicalProcess'
 #: Represents the BEL function, pathology()
 PATHOLOGY = 'Pathology'
 
+#: Represents the BEL function, populationAbundance()
+POPULATION = 'Population'
+
 #: Represents the BEL abundance, compositeAbundance()
 COMPOSITE = 'Composite'
 
@@ -323,7 +228,8 @@ PYBEL_NODE_FUNCTIONS = {
     PATHOLOGY,
     COMPOSITE,
     COMPLEX,
-    REACTION
+    REACTION,
+    POPULATION,
 }
 
 #: The mapping from PyBEL node functions to BEL strings
@@ -336,7 +242,8 @@ rev_abundance_labels = {
     BIOPROCESS: 'bp',
     PATHOLOGY: 'path',
     COMPLEX: 'complex',
-    COMPOSITE: 'composite'
+    COMPOSITE: 'composite',
+    POPULATION: 'pop',
 }
 
 # Internal edge data keys
@@ -382,12 +289,8 @@ HAS_REACTANT = 'hasReactant'
 #: A BEL relationship
 HAS_PRODUCT = 'hasProduct'
 #: A BEL relationship
-HAS_COMPONENT = 'hasComponent'
-#: A BEL relationship
 HAS_VARIANT = 'hasVariant'
 #: A BEL relationship
-HAS_MEMBER = 'hasMember'
-#: A BEL relationship
 #: :data:`GENE` to :data:`RNA` is called transcription
 TRANSCRIBED_TO = 'transcribedTo'
 #: A BEL relationship
@@ -406,6 +309,12 @@ CAUSES_NO_CHANGE = 'causesNoChange'
 #: A BEL relationship
 REGULATES = 'regulates'
 #: A BEL relationship
+BINDS = 'binds'
+#: A BEL relationship
+CORRELATION = 'correlation'
+#: A BEL relationship
+NO_CORRELATION = 'noCorrelation'
+#: A BEL relationship
 NEGATIVE_CORRELATION = 'negativeCorrelation'
 #: A BEL relationship
 POSITIVE_CORRELATION = 'positiveCorrelation'
@@ -443,34 +352,38 @@ CAUSAL_POLAR_RELATIONS = CAUSAL_INCREASE_RELATIONS | CAUSAL_DECREASE_RELATIONS
 #: A set of all causal relationships
 CAUSAL_RELATIONS = CAUSAL_INCREASE_RELATIONS | CAUSAL_DECREASE_RELATIONS | {REGULATES}
 
-#: A set of all relationships that are inherently directionless, and are therefore added to the graph twice
-TWO_WAY_RELATIONS = {
-    NEGATIVE_CORRELATION,
+APOLAR_CORRELATIVE_RELATIONS = {
+    CORRELATION,
+    NO_CORRELATION,
+}
+
+POLAR_CORRELATIVE_RELATIONS = {
     POSITIVE_CORRELATION,
+    NEGATIVE_CORRELATION,
+}
+
+#: A set of all correlative relationships
+CORRELATIVE_RELATIONS = APOLAR_CORRELATIVE_RELATIONS | POLAR_CORRELATIVE_RELATIONS
+
+#: A set of polar relations
+POLAR_RELATIONS = CAUSAL_POLAR_RELATIONS | POLAR_CORRELATIVE_RELATIONS
+
+#: A set of all relationships that are inherently directionless, and are therefore added to the graph twice
+TWO_WAY_RELATIONS = CORRELATIVE_RELATIONS | {
     ASSOCIATION,
     ORTHOLOGOUS,
     ANALOGOUS_TO,
     EQUIVALENT_TO,
+    BINDS,
 }
 
-#: A set of all correlative relationships
-CORRELATIVE_RELATIONS = {
-    POSITIVE_CORRELATION,
-    NEGATIVE_CORRELATION
-}
-
-#: A set of polar relations
-POLAR_RELATIONS = CAUSAL_POLAR_RELATIONS | CORRELATIVE_RELATIONS
-
 #: A list of relationship types that don't require annotations or evidence
 UNQUALIFIED_EDGES = {
     HAS_REACTANT,
     HAS_PRODUCT,
-    HAS_COMPONENT,
     HAS_VARIANT,
     TRANSCRIBED_TO,
     TRANSLATED_TO,
-    HAS_MEMBER,
     IS_A,
     EQUIVALENT_TO,
     PART_OF,
@@ -519,7 +432,6 @@ GRAPH_ANNOTATION_PATTERN = 'annotation_pattern'
 GRAPH_ANNOTATION_LIST = 'annotation_list'
 GRAPH_WARNINGS = 'warnings'
 GRAPH_PYBEL_VERSION = 'pybel_version'
-GRAPH_UNCACHED_NAMESPACES = 'namespaces_uncached'
 GRAPH_PATH = 'path'
 
 #: The key for the document name. Can be accessed by :code:`graph.document[METADATA_NAME]` or by using the property
@@ -576,7 +488,7 @@ REQUIRED_METADATA = {
     METADATA_VERSION,
     METADATA_DESCRIPTION,
     METADATA_AUTHORS,
-    METADATA_CONTACT
+    METADATA_CONTACT,
 }
 
 # Modifier parser constants
@@ -631,14 +543,17 @@ belns_encodings = {
     'A': {ABUNDANCE, RNA, MIRNA, PROTEIN, GENE, COMPLEX},
     'B': {PATHOLOGY, BIOPROCESS},
     'O': {PATHOLOGY},
-    'C': {COMPLEX}
+    'C': {COMPLEX},
 }
 
 BELNS_ENCODING_STR = ''.join(sorted(belns_encodings))
 
 PYBEL_REMOTE_HOST = 'PYBEL_REMOTE_HOST'
 PYBEL_REMOTE_USER = 'PYBEL_REMOTE_USER'
-PYBEL_REMOTE_PASSWORD = 'PYBEL_REMOTE_PASSWORD'
+PYBEL_REMOTE_PASSWORD = 'PYBEL_REMOTE_PASSWORD'  # noqa: S105
 
 #: The default location of PyBEL Web
 DEFAULT_SERVICE_URL = 'https://bel-commons.scai.fraunhofer.de'
+
+PYBEL_PUBMED = '29048466'
+SET_CITATION_FMT = 'SET Citation = {{"{}", "{}"}}'
