@@ -18,33 +18,40 @@ from ..constants import (
 from ..language import Entity
 
 __all__ = [
+    # Base Classes
+    'Entity',
+    'BaseEntity',
+    'BaseAbundance',
+    'ListAbundance',
+
+    # Named entities
     'Abundance',
+    'BiologicalProcess',
+    'Pathology',
+    'Population',
+    'NamedComplexAbundance',
 
     # Central Dogma Stuff
+    'CentralDogma',
     'Gene',
+    'Transcribable',
     'Rna',
     'MicroRna',
     'Protein',
 
     # Fusions
+    'FusionBase',
     'ProteinFusion',
     'RnaFusion',
     'GeneFusion',
 
     # Fusion Ranges
+    'FusionRangeBase',
     'EnumeratedFusionRange',
     'MissingFusionRange',
 
-    # Transformations
-    'ComplexAbundance',
-    'CompositeAbundance',
-    'BiologicalProcess',
-    'Pathology',
-    'Population',
-    'NamedComplexAbundance',
-    'Reaction',
-
     # Variants
+    'Variant',
     'ProteinModification',
     'GeneModification',
     'Hgvs',
@@ -53,15 +60,10 @@ __all__ = [
     'ProteinSubstitution',
     'Fragment',
 
-    # Base Classes
-    'Entity',
-    'BaseEntity',
-    'BaseAbundance',
-    'CentralDogma',
-    'ListAbundance',
-    'Variant',
-    'FusionBase',
-    'FusionRangeBase',
+    # List Entities
+    'ComplexAbundance',
+    'CompositeAbundance',
+    'Reaction',
 ]
 
 # A methodcaller for the key argument of sorted()
@@ -69,15 +71,20 @@ _as_bel = methodcaller('as_bel')
 
 
 class BaseEntity(dict, metaclass=ABCMeta):
-    """This class represents all BEL nodes.
+    """This is the superclass for all BEL terms.
 
-    It can be converted to a tuple and hashed.
+    A BEL term has three properties:
+
+    1. It has a type. Subclasses of this function should set the class variable
+       ``function``.
+    2. It can be converted to BEL. Note, this is an abstract class, so all sub-classes
+       must implement this functionality in ``as_bel()``.
+    3. It can be hashed, based on the BEL conversion
     """
 
     function = ...
 
     def __init__(self) -> None:
-        """Build a PyBEL node."""
         super().__init__(**{FUNCTION: self.function})
         self._md5 = None
 
@@ -109,35 +116,8 @@ class BaseEntity(dict, metaclass=ABCMeta):
         return self.as_bel()
 
 
-class BaseAbundance(BaseEntity):
-    """The superclass for building node data dictionaries.
-
-    This class must be subclassed and the class variable `function` must be
-    overridden.
-    """
-
-    def __init__(
-        self,
-        namespace: str,
-        name: Optional[str] = None,
-        identifier: Optional[str] = None,
-        xrefs: Optional[List[Entity]] = None,
-    ) -> None:
-        """Build an abundance from a function, namespace, and a name and/or identifier.
-
-        :param namespace: The name of the namespace
-        :param name: The name of this abundance
-        :param identifier: The database identifier for this abundance
-        :param xrefs: Alternate identifiers for the entity
-        """
-        super().__init__()
-        self[CONCEPT] = Entity(
-            namespace=namespace,
-            name=name,
-            identifier=identifier,
-        )
-        if xrefs:
-            self[XREFS] = xrefs
+class BaseConcept(dict):
+    """A dictionary containing a concept entry."""
 
     @property
     def entity(self) -> Entity:  # noqa:D401
@@ -174,6 +154,45 @@ class BaseAbundance(BaseEntity):
         """The OBO-style identifier for this node."""
         return self.entity.obo
 
+
+class BaseAbundance(BaseEntity, BaseConcept):
+    """The superclass for all named BEL terms.
+
+    A named BEL term has:
+
+    1. A type (taken care of by being a subclass of :class:`BaseEntity`)
+    2. A named :class:`Entity`. Though this doesn't directly inherit from
+       :class:`Entity`, it creates one internally using the namespace,
+       identifier, and name. Ideally, both the identifier and name are given.
+       If one is missing, it can be looked up with :func:`pybel.grounding.ground`
+    3. An optional list of xrefs, corresponding to the whole entity,
+       not just the namespace/name. For example, the BEL term
+       ``p(HGNC:APP, frag(672_713)`` could xref CHEBI:64647.
+    """
+
+    def __init__(
+        self,
+        namespace: str,
+        name: Optional[str] = None,
+        identifier: Optional[str] = None,
+        xrefs: Optional[List[Entity]] = None,
+    ) -> None:
+        """Build an abundance from a function, namespace, and a name and/or identifier.
+
+        :param namespace: The name of the namespace
+        :param name: The name of this abundance
+        :param identifier: The database identifier for this abundance
+        :param xrefs: Alternate identifiers for the entity
+        """
+        super().__init__()
+        self[CONCEPT] = Entity(
+            namespace=namespace,
+            name=name,
+            identifier=identifier,
+        )
+        if xrefs:
+            self[XREFS] = xrefs
+
     def as_bel(self, use_identifiers: bool = True) -> str:
         """Return this node as a BEL string."""
         return "{}({})".format(
@@ -185,9 +204,8 @@ class BaseAbundance(BaseEntity):
 class Abundance(BaseAbundance):
     """Builds an abundance node.
 
-    Example:
+    >>> from pybel.dsl import Abundance
     >>> Abundance(namespace='CHEBI', name='water')
-
     """
 
     function = ABUNDANCE
@@ -196,9 +214,8 @@ class Abundance(BaseAbundance):
 class BiologicalProcess(BaseAbundance):
     """Builds a biological process node.
 
-    Example:
+    >>> from pybel.dsl import BiologicalProcess
     >>> BiologicalProcess(namespace='GO', name='apoptosis')
-
     """
 
     function = BIOPROCESS
@@ -207,20 +224,18 @@ class BiologicalProcess(BaseAbundance):
 class Pathology(BaseAbundance):
     """Build a pathology node.
 
-    Example:
+    >>> from pybel.dsl import Pathology
     >>> Pathology(namespace='DO', name='Alzheimer Disease')
-
     """
 
     function = PATHOLOGY
 
 
 class Population(BaseAbundance):
-    """Builds a popuation node.
+    """Builds a population node.
 
-    Example:
+    >>> from pybel.dsl import Population
     >>> Population(namespace='uberon', name='blood')
-
     """
 
     function = POPULATION
@@ -294,12 +309,10 @@ class CentralDogma(BaseAbundance):
     def get_parent(self) -> Optional['CentralDogma']:
         """Get the parent, or none if it's already a reference node.
 
-        Example usage:
-
+        >>> from pybel.dsl import Protein, Fragment
         >>> ab42 = Protein(name='APP', namespace='HGNC', variants=[Fragment(start=672, stop=713)])
         >>> app = ab42.get_parent()
         >>> assert 'p(HGNC:APP)' == app.as_bel()
-
         """
         if VARIANTS not in self:
             return None
@@ -316,12 +329,10 @@ class CentralDogma(BaseAbundance):
 
         :param variants: An optional variant or list of variants
 
-        Example Usage:
-
+        >>> from pybel.dsl import Protein, Fragment
         >>> app = Protein(name='APP', namespace='HGNC')
         >>> ab42 = app.with_variants([Fragment(start=672, stop=713)])
         >>> assert 'p(HGNC:APP, frag(672_713))' == ab42.as_bel()
-
         """
         return self.__class__(
             namespace=self.namespace,
@@ -332,9 +343,44 @@ class CentralDogma(BaseAbundance):
         )
 
 
-class ProteinModification(Variant):
+class EntityVariant(Variant, BaseConcept):
+    """A variant that contains a reference."""
+
+    function = ...
+
+    def __init__(
+        self,
+        name: str,
+        namespace: Optional[str] = None,
+        identifier: Optional[str] = None,
+        xrefs: Optional[List[Entity]] = None,
+    ) -> None:
+        """Build a variant that has a reference.
+
+        :param name: The name of the modification
+        :param namespace: The namespace to which the name of this modification belongs
+        :param identifier: The identifier of the name of the modification
+        :param xrefs: Alternative database xrefs
+
+        Either the name or the identifier must be used. If the namespace is omitted, it is assumed that a name is
+        specified from the BEL default namespace.
+        """
+        super().__init__(kind=self.function)
+
+        self[CONCEPT] = Entity(
+            namespace=(namespace or BEL_DEFAULT_NAMESPACE),
+            name=name,
+            identifier=identifier,
+        )
+        if xrefs:
+            self['xref'] = xrefs
+
+
+class ProteinModification(EntityVariant):
     """Build a protein modification variant dictionary."""
 
+    function = PMOD
+
     def __init__(
         self,
         name: str,
@@ -358,27 +404,27 @@ class ProteinModification(Variant):
 
         Example from BEL default namespace:
 
+        >>> from pybel.dsl import ProteinModification
         >>> ProteinModification('Ph', code='Thr', position=308)
 
         Example from custom namespace:
 
+        >>> from pybel.dsl import ProteinModification
         >>> ProteinModification(name='protein phosphorylation', namespace='GO', code='Thr', position=308)
 
         Example from custom namespace additionally qualified with identifier:
 
+        >>> from pybel.dsl import ProteinModification
         >>> ProteinModification(name='protein phosphorylation', namespace='GO',
-        >>>                     identifier='GO:0006468', code='Thr', position=308)
+        >>>                     identifier='0006468', code='Thr', position=308)
 
         """
-        super().__init__(kind=PMOD)
-
-        self[CONCEPT] = Entity(
-            namespace=(namespace or BEL_DEFAULT_NAMESPACE),
+        super().__init__(
             name=name,
+            namespace=namespace,
             identifier=identifier,
+            xrefs=xrefs,
         )
-        if xrefs:
-            self['xref'] = xrefs
 
         if code:
             self[PMOD_CODE] = code
@@ -386,11 +432,6 @@ class ProteinModification(Variant):
         if position:
             self[PMOD_POSITION] = position
 
-    @property
-    def entity(self) -> Entity:  # noqa:D401
-        """The concept for this protein modification."""
-        return self[CONCEPT]
-
     def as_bel(self, use_identifiers: bool = True) -> str:
         """Return this protein modification variant as a BEL string."""
         if use_identifiers and self.entity.identifier and self.entity.name:
@@ -404,47 +445,24 @@ class ProteinModification(Variant):
         )
 
 
-class GeneModification(Variant):
-    """Build a gene modification variant dictionary."""
+class GeneModification(EntityVariant):
+    """Build a gene modification variant dictionary.
 
-    def __init__(
-        self,
-        name: str,
-        namespace: Optional[str] = None,
-        identifier: Optional[str] = None,
-        xrefs: Optional[List[Entity]] = None,
-    ) -> None:
-        """Build a gene modification variant data dictionary.
+    Either the name or the identifier must be used. If the namespace is omitted, it is assumed that a name is
+    specified from the BEL default namespace.
 
-        :param name: The name of the gene modification
-        :param namespace: The namespace of the gene modification
-        :param identifier: The identifier of the name in the database
+    Example from BEL default namespace:
 
-        Either the name or the identifier must be used. If the namespace is omitted, it is assumed that a name is
-        specified from the BEL default namespace.
+    >>> from pybel.dsl import GeneModification
+    >>> GeneModification(name='Me')
 
-        Example from BEL default namespace:
+    Example from custom namespace:
 
-        >>> GeneModification(name='Me')
+    >>> from pybel.dsl import GeneModification
+    >>> GeneModification(name='DNA methylation', namespace='GO', identifier='0006306',)
+    """
 
-        Example from custom namespace:
-
-        >>> GeneModification(name='DNA methylation', namespace='GO', identifier='GO:0006306',)
-        """
-        super().__init__(kind=GMOD)
-
-        self[CONCEPT] = Entity(
-            namespace=(namespace or BEL_DEFAULT_NAMESPACE),
-            name=name,
-            identifier=identifier,
-        )
-        if xrefs:
-            self[XREFS] = xrefs
-
-    @property
-    def entity(self) -> Entity:
-        """Represent the entity in this gene modification."""
-        return self[CONCEPT]
+    function = GMOD
 
     def as_bel(self, use_identifiers: bool = True) -> str:
         """Return this gene modification variant as a BEL string."""
@@ -464,9 +482,8 @@ class Hgvs(Variant):
 
         :param variant: The HGVS variant string
 
-        Example:
+        >>> from pybel.dsl import Protein, Hgvs
         >>> Protein(namespace='HGNC', name='AKT1', variants=[Hgvs('p.Ala127Tyr')])
-
         """
         super().__init__(kind=HGVS)
         self[HGVS] = variant
@@ -505,7 +522,7 @@ class ProteinSubstitution(Hgvs):
         :param position: The position of the residue
         :param to_aa: The 3-letter amino acid code of the new residue
 
-        Example:
+        >>> from pybel.dsl import Protein, ProteinSubstitution
         >>> Protein(namespace='HGNC', name='AKT1', variants=[ProteinSubstitution('Ala', 127, 'Tyr')])
 
         """
@@ -529,10 +546,12 @@ class Fragment(Variant):
 
         Example of specified fragment:
 
+        >>> from pybel.dsl import Protein, Fragment
         >>> Protein(name='APP', namespace='HGNC', variants=[Fragment(start=672, stop=713)])
 
         Example of unspecified fragment:
 
+        >>> from pybel.dsl import Protein, Fragment
         >>> Protein(name='APP', namespace='HGNC', variants=[Fragment()])
 
         """
@@ -582,7 +601,7 @@ class Gene(CentralDogma):
         )
 
 
-class _Transcribable(CentralDogma):
+class Transcribable(CentralDogma):
     """A base class for RNA and micro-RNA to share getting of their corresponding genes."""
 
     def get_gene(self) -> Gene:
@@ -601,22 +620,24 @@ class _Transcribable(CentralDogma):
         )
 
 
-class Rna(_Transcribable):
+class Rna(Transcribable):
     """Builds an RNA node.
 
     Example: AKT1 protein coding gene's RNA:
 
+    >>> from pybel.dsl import Rna
     >>> Rna(namespace='HGNC', name='AKT1', identifier='391')
 
     Non-coding RNAs can also be encoded such as `U85 <https://www-snorna.biotoul.fr/plus.php?id=U85>`_:
 
+    >>> from pybel.dsl import Rna
     >>> Rna(namespace='SNORNABASE', identifier='SR0000073')
     """
 
     function = RNA
 
 
-class MicroRna(_Transcribable):
+class MicroRna(Transcribable):
     """Represents an micro-RNA.
 
     Human miRNA's are listed on HUGO's `MicroRNAs (MIR) <https://www.genenames.org/cgi-bin/genefamilies/set/476>`_
@@ -624,14 +645,17 @@ class MicroRna(_Transcribable):
 
     MIR1-1 from `HGNC <https://www.genenames.org/cgi-bin/gene_symbol_report?hgnc_id=31499>`_:
 
+    >>> from pybel.dsl import MicroRna
     >>> MicroRna(namespace='HGNC', name='MIR1-1', identifier='31499')
 
     MIR1-1 from `miRBase <http://www.mirbase.org/cgi-bin/mirna_entry.pl?acc=MI0000651>`_:
 
+    >>> from pybel.dsl import MicroRna
     >>> MicroRna(namespace='MIRBASE', identifier='MI0000651')
 
     MIR1-1 from `Entrez Gene <https://view.ncbi.nlm.nih.gov/gene/406904>`_
 
+    >>> from pybel.dsl import MicroRna
     >>> MicroRna(namespace='ENTREZ', identifier='406904')
     """
 
@@ -643,14 +667,17 @@ class Protein(CentralDogma):
 
     Example: AKT
 
+    >>> from pybel.dsl import Protein
     >>> Protein(namespace='HGNC', name='AKT1')
 
     Example: AKT with optionally included HGNC database identifier
 
+    >>> from pybel.dsl import Protein
     >>> Protein(namespace='HGNC', name='AKT1', identifier='391')
 
     Example: AKT with phosphorylation
 
+    >>> from pybel.dsl import Protein, ProteinModification
     >>> Protein(namespace='HGNC', name='AKT', variants=[ProteinModification('Ph', code='Thr', position=308)])
     """
 
@@ -695,7 +722,7 @@ class Reaction(BaseEntity):
         :param reactants: A list of PyBEL node data dictionaries representing the reactants
         :param products: A list of PyBEL node data dictionaries representing the products
 
-        Example:
+        >>> from pybel.dsl import Reaction, Protein, Abundance
         >>> Reaction([Protein(namespace='HGNC', name='KNG1')], [Abundance(namespace='CHEBI', name='bradykinin')])
 
         """
@@ -742,7 +769,7 @@ class Reaction(BaseEntity):
 
 
 class ListAbundance(BaseEntity):
-    """The superclass for building list abundance (complex, abundance) node data dictionaries."""
+    """The superclass for all BEL terms defined by lists, as opposed to by names like in :class:`BaseAbundance`."""
 
     def __init__(self, members: Union[BaseAbundance, Iterable[BaseAbundance]]) -> None:
         """Build a list abundance node.
@@ -817,16 +844,30 @@ class ComplexAbundance(ListAbundance):
 class NamedComplexAbundance(BaseAbundance):
     """Build a named complex abundance node.
 
-    Example:
+    >>> from pybel.dsl import NamedComplexAbundance
     >>> NamedComplexAbundance(namespace='FPLX', name='Calcineurin Complex')
-
     """
 
     function = COMPLEX
 
 
 class CompositeAbundance(ListAbundance):
-    """Build a composite abundance node."""
+    """Build a composite abundance node.
+
+    This node is effectively the "AND" inside BEL, which can help
+    represent when two things need to be true at the same time. For
+    example, in COVID 19, if both the NF-KB and IL6-STAT complex are
+    present, then acute respiratory distress syndrome happens.
+
+    >>> from pybel.dsl import CompositeAbundance, ComplexAbundance, Protein, NamedComplexAbundance
+    >>> CompositeAbundance([
+    ...     NamedComplexAbundance('fplx', 'nfkb'),
+    ...     ComplexAbundance([
+    ...         Protein('hgnc', identifier='6018', name='IL6'),
+    ...         Protein('hgnc', identifier='11364', name='STAT3'),
+    ...     ]),
+    ... ])
+    """
 
     function = COMPOSITE
 
@@ -963,6 +1004,7 @@ class RnaFusion(FusionBase):
 
     Example, with fusion ranges using the 'r' qualifier:
 
+    >>> from pybel.dsl import RnaFusion, Rna
     >>> RnaFusion(
     >>> ... partner_5p=Rna(namespace='HGNC', name='TMPRSS2'),
     >>> ... range_5p=EnumeratedFusionRange('r', 1, 79),
@@ -973,6 +1015,7 @@ class RnaFusion(FusionBase):
 
     Example with missing fusion ranges:
 
+    >>> from pybel.dsl import RnaFusion, Rna
     >>> RnaFusion(
     >>> ... partner_5p=Rna(namespace='HGNC', name='TMPRSS2'),
     >>> ... partner_3p=Rna(namespace='HGNC', name='ERG'),
@@ -988,6 +1031,7 @@ class GeneFusion(FusionBase):
 
     Example, using fusion ranges with the 'c' qualifier
 
+    >>> from pybel.dsl import GeneFusion, Gene
     >>> GeneFusion(
     >>> ... partner_5p=Gene(namespace='HGNC', name='TMPRSS2'),
     >>> ... range_5p=EnumeratedFusionRange('c', 1, 79),
@@ -997,6 +1041,7 @@ class GeneFusion(FusionBase):
 
     Example with missing fusion ranges:
 
+    >>> from pybel.dsl import GeneFusion, Gene
     >>> GeneFusion(
     >>> ... partner_5p=Gene(namespace='HGNC', name='TMPRSS2'),
     >>> ... partner_3p=Gene(namespace='HGNC', name='ERG'),
