@@ -29,11 +29,12 @@
     UNSET ALL
 """
 
-from ..dsl import abundance, activity, bioprocess, complex_abundance, pmod, protein
+from ..dsl import Abundance, BiologicalProcess, ComplexAbundance, Entity, Protein, ProteinModification, activity
+from ..resources import CHEBI_URL, CONFIDENCE_URL, GO_URL, HGNC_URL, SPECIES_PATTERN
 from ..struct.graph import BELGraph
 
 __all__ = [
-    'sialic_acid_graph'
+    'sialic_acid_graph',
 ]
 
 citation = '26438529'
@@ -53,33 +54,40 @@ sialic_acid_graph = BELGraph(
     version='1.0.0',
     description="The downstream effects of sialic acid in immune signaling",
     authors='Charles Tapley Hoyt',
-    contact='charles.hoyt@scai.fraunhofer.de',
+    contact='cthoyt@gmail.com',
 )
 
 sialic_acid_graph.namespace_url.update({
-    'HGNC': 'https://arty.scai.fraunhofer.de/artifactory/bel/namespace/hgnc-human-genes/'
-            'hgnc-human-genes-20170725.belns',
-    'CHEBI': 'https://arty.scai.fraunhofer.de/artifactory/bel/namespace/chebi/chebi-20170725.belns',
-    'GOBP': 'https://arty.scai.fraunhofer.de/artifactory/bel/namespace/go-biological-process/'
-            'go-biological-process-20170725.belns'
+    'HGNC': HGNC_URL,
+    'CHEBI': CHEBI_URL,
+    'GO': GO_URL,
 })
 
 sialic_acid_graph.annotation_url.update({
-    'Confidence': 'https://arty.scai.fraunhofer.de/artifactory/bel/annotation/confidence/confidence-1.0.0.belanno',
-    'Species': 'https://arty.scai.fraunhofer.de/artifactory/bel/annotation/species-taxonomy-id/'
-               'species-taxonomy-id-20170511.belanno'
+    'Confidence': CONFIDENCE_URL,
 })
 
-sialic_acid = abundance(name='sialic acid', namespace='CHEBI', identifier='26667')
-cd33 = protein(name='CD33', namespace='HGNC', identifier='1659')
-sialic_acid_cd33_complex = complex_abundance([sialic_acid, cd33])
-shp1 = protein(namespace='HGNC', name='PTPN6', identifier='9658')
-shp2 = protein(namespace='HGNC', name='PTPN11', identifier='9644')
-syk = protein(namespace='HGNC', name='SYK', identifier='11491')
-dap12 = protein(namespace='HGNC', name='TYROBP', identifier='12449')
-trem2 = protein(namespace='HGNC', name='TREM2', identifier='17761')
-cd33_phosphorylated = protein(name='CD33', namespace='HGNC', identifier='1659', variants=[pmod('Ph')])
-immune_response = bioprocess(name='immune response', namespace='GOBP', identifier='0006955')
+sialic_acid_graph.annotation_pattern.update({
+    'Species': SPECIES_PATTERN,
+})
+
+sialic_acid = Abundance(name='sialic acid', namespace='CHEBI', identifier='26667')
+cd33 = Protein(
+    name='CD33',
+    namespace='HGNC',
+    identifier='1659',
+    xrefs=[
+        Entity(namespace='uniprot', identifier='P20138'),
+    ],
+)
+sialic_acid_cd33_complex = ComplexAbundance([sialic_acid, cd33])
+shp1 = Protein(namespace='HGNC', name='PTPN6', identifier='9658')
+shp2 = Protein(namespace='HGNC', name='PTPN11', identifier='9644')
+syk = Protein(namespace='HGNC', name='SYK', identifier='11491')
+dap12 = Protein(namespace='HGNC', name='TYROBP', identifier='12449')
+trem2 = Protein(namespace='HGNC', name='TREM2', identifier='17761')
+cd33_phosphorylated = Protein(name='CD33', namespace='HGNC', identifier='1659', variants=ProteinModification('Ph'))
+immune_response = BiologicalProcess(name='immune response', namespace='GO', identifier='0006955')
 
 sialic_acid_graph.add_increases(
     sialic_acid_cd33_complex,
@@ -87,7 +95,7 @@ sialic_acid_graph.add_increases(
     citation=citation,
     annotations={'Species': '9606', 'Confidence': 'High'},
     evidence=evidence_1,
-    object_modifier=activity()
+    object_modifier=activity(),
 )
 
 sialic_acid_graph.add_increases(
@@ -96,7 +104,7 @@ sialic_acid_graph.add_increases(
     citation=citation,
     annotations={'Species': '9606', 'Confidence': 'High'},
     evidence=evidence_1,
-    subject_modifier=activity()
+    subject_modifier=activity(),
 )
 
 sialic_acid_graph.add_directly_increases(
@@ -126,7 +134,7 @@ sialic_acid_graph.add_directly_decreases(
     evidence=evidence_2,
     annotations={'Species': '9606', 'Confidence': 'High'},
     subject_modifier=activity(),
-    object_modifier=activity()
+    object_modifier=activity(),
 )
 
 sialic_acid_graph.add_directly_decreases(
@@ -136,7 +144,7 @@ sialic_acid_graph.add_directly_decreases(
     evidence=evidence_2,
     annotations={'Species': '9606', 'Confidence': 'High'},
     subject_modifier=activity(),
-    object_modifier=activity()
+    object_modifier=activity(),
 )
 
 sialic_acid_graph.add_increases(
@@ -146,7 +154,7 @@ sialic_acid_graph.add_increases(
     evidence=evidence_2,
     annotations={'Species': '9606', 'Confidence': 'Low'},
     subject_modifier=activity(),
-    object_modifier=activity()
+    object_modifier=activity(),
 )
 
 sialic_acid_graph.add_increases(
@@ -156,5 +164,5 @@ sialic_acid_graph.add_increases(
     evidence=evidence_2,
     annotations={'Species': '9606', 'Confidence': 'Low'},
     subject_modifier=activity(),
-    object_modifier=activity()
+    object_modifier=activity(),
 )
