@@ -11,17 +11,20 @@ from .cache_manager import Manager
 
 __all__ = [
     'to_database',
-    'from_database'
+    'from_database',
 ]
 
-log = logging.getLogger(__name__)
+logger = logging.getLogger(__name__)
 
 
-def to_database(graph, manager: Optional[Manager] = None, store_parts: bool = True, use_tqdm: bool = False):
+def to_database(
+    graph,
+    manager: Optional[Manager] = None,
+    use_tqdm: bool = False,
+):
     """Store a graph in a database.
 
     :param BELGraph graph: A BEL graph
-    :param store_parts: Should the graph be stored in the edge store?
     :return: If successful, returns the network object from the database.
     :rtype: Optional[Network]
     """
@@ -29,16 +32,20 @@ def to_database(graph, manager: Optional[Manager] = None, store_parts: bool = Tr
         manager = Manager()
 
     try:
-        return manager.insert_graph(graph, store_parts=store_parts, use_tqdm=use_tqdm)
+        return manager.insert_graph(graph, use_tqdm=use_tqdm)
     except (IntegrityError, OperationalError):
         manager.session.rollback()
-        log.exception('Error storing graph')
+        logger.exception('Error storing graph')
     except Exception as e:
         manager.session.rollback()
         raise e
 
 
-def from_database(name: str, version: Optional[str] = None, manager: Optional[Manager] = None):
+def from_database(
+    name: str,
+    version: Optional[str] = None,
+    manager: Optional[Manager] = None,
+):
     """Load a BEL graph from a database.
 
     If name and version are given, finds it exactly with
