@@ -9,7 +9,7 @@ from .typing import EdgePredicate
 from .utils import part_has_modifier
 from ..graph import BELGraph
 from ...constants import (
-    ACTIVITY, ANNOTATIONS, ASSOCIATION, CAUSAL_RELATIONS, CITATION, CITATION_AUTHORS, CITATION_TYPE,
+    ACTIVITY, ANNOTATIONS, ASSOCIATION, CAUSAL_RELATIONS, CITATION, CITATION_AUTHORS, CITATION_DB,
     CITATION_TYPE_PUBMED, DEGRADATION, DIRECT_CAUSAL_RELATIONS, EVIDENCE, OBJECT, POLAR_RELATIONS, RELATION, SUBJECT,
     TRANSLOCATION,
 )
@@ -23,6 +23,7 @@ __all__ = [
     'has_pubmed',
     'has_authors',
     'is_causal_relation',
+    'not_causal_relation',
     'is_direct_causal_relation',
     'is_associative_relation',
     'has_polarity',
@@ -74,7 +75,7 @@ def has_provenance(edge_data: EdgeData) -> bool:
 @edge_predicate
 def has_pubmed(edge_data: EdgeData) -> bool:
     """Check if the edge has a PubMed citation."""
-    return CITATION in edge_data and CITATION_TYPE_PUBMED == edge_data[CITATION][CITATION_TYPE]
+    return CITATION in edge_data and CITATION_TYPE_PUBMED == edge_data[CITATION][CITATION_DB]
 
 
 @edge_predicate
@@ -89,6 +90,12 @@ def is_causal_relation(edge_data: EdgeData) -> bool:
     return edge_data[RELATION] in CAUSAL_RELATIONS
 
 
+@edge_predicate
+def not_causal_relation(edge_data: EdgeData) -> bool:
+    """Check if the given relation is not causal."""
+    return edge_data[RELATION] not in CAUSAL_RELATIONS
+
+
 @edge_predicate
 def is_direct_causal_relation(edge_data: EdgeData) -> bool:
     """Check if the edge is a direct causal relation."""
@@ -164,7 +171,7 @@ def has_pathology_causal(graph: BELGraph, u: BaseEntity, v: BaseEntity, k: str)
     :return: If the subject of this edge is a pathology and it participates in a causal reaction.
     """
     return (
-        isinstance(u, Pathology) and
-        is_causal_relation(graph, u, v, k) and
-        not isinstance(v, (Pathology, BiologicalProcess))
+        isinstance(u, Pathology)
+        and is_causal_relation(graph, u, v, k)
+        and not isinstance(v, (Pathology, BiologicalProcess))
     )
