@@ -6,7 +6,4 @@ from . import neighborhood, upstream
 from .neighborhood import *
 from .upstream import *
 
-__all__ = (
-    neighborhood.__all__ +
-    upstream.__all__
-)
+__all__ = neighborhood.__all__ + upstream.__all__
