@@ -9,8 +9,8 @@ from .node_summary import *
 from .provenance import *
 
 __all__ = (
-    errors.__all__ +
-    node_summary.__all__ +
-    provenance.__all__ +
-    edge_summary.__all__
+    errors.__all__
+    + node_summary.__all__
+    + provenance.__all__
+    + edge_summary.__all__
 )
