@@ -3,14 +3,16 @@
 """Summary functions for nodes in BEL graphs."""
 
 import itertools as itt
+import typing
 from collections import Counter, defaultdict
+from typing import Any, Iterable, List, Mapping, Optional, Set, Tuple
 
 from ..filters.node_predicates import has_variant
 from ...constants import (
-    ACTIVITY, EFFECT, FROM_LOC, FUSION, IDENTIFIER, KIND, LOCATION, MEMBERS, MODIFIER, NAME, NAMESPACE,
-    OBJECT, PARTNER_3P, PARTNER_5P, SUBJECT, TO_LOC, TRANSLOCATION, VARIANTS,
+    ACTIVITY, CONCEPT, EFFECT, FROM_LOC, FUSION, KIND, LOCATION, MEMBERS, MODIFIER, NAME, NAMESPACE, OBJECT, PARTNER_3P,
+    PARTNER_5P, SUBJECT, TO_LOC, TRANSLOCATION, VARIANTS,
 )
-from ...dsl import Pathology
+from ...dsl import BaseEntity, Pathology
 
 __all__ = [
     'get_functions',
@@ -28,46 +30,41 @@ __all__ = [
 ]
 
 
-def _function_iterator(graph):
-    """Iterate over the functions in a graph.
-
-    :rtype: iter[str]
-    """
+def _function_iterator(graph) -> Iterable[str]:
+    """Iterate over the functions in a graph."""
     return (
         node.function
         for node in graph
     )
 
 
-def get_functions(graph):
+def get_functions(graph) -> Set[str]:
     """Get the set of all functions used in this graph.
 
     :param pybel.BELGraph graph: A BEL graph
     :return: A set of functions
-    :rtype: set[str]
     """
     return set(_function_iterator(graph))
 
 
-def count_functions(graph):
+def count_functions(graph) -> typing.Counter[str]:
     """Count the frequency of each function present in a graph.
 
     :param pybel.BELGraph graph: A BEL graph
     :return: A Counter from {function: frequency}
-    :rtype: collections.Counter
     """
     return Counter(_function_iterator(graph))
 
 
-def _iterate_namespaces(graph):
+def _iterate_namespaces(graph) -> Iterable[str]:
     return (
-        node[NAMESPACE]
+        node[CONCEPT][NAMESPACE]
         for node in graph
-        if NAMESPACE in node
+        if CONCEPT in node
     )
 
 
-def count_namespaces(graph):
+def count_namespaces(graph) -> typing.Counter[str]:
     """Count the frequency of each namespace across all nodes (that have namespaces).
 
     :param pybel.BELGraph graph: A BEL graph
@@ -77,27 +74,25 @@ def count_namespaces(graph):
     return Counter(_iterate_namespaces(graph))
 
 
-def get_namespaces(graph):
+def get_namespaces(graph) -> Set[str]:
     """Get the set of all namespaces used in this graph.
 
     :param pybel.BELGraph graph: A BEL graph
     :return: A set of namespaces
-    :rtype: set[str]
     """
     return set(_iterate_namespaces(graph))
 
 
-def get_unused_namespaces(graph):
+def get_unused_namespaces(graph) -> Set[str]:
     """Get the set of all namespaces that are defined in a graph, but are never used.
 
     :param pybel.BELGraph graph: A BEL graph
     :return: A set of namespaces that are included but not used
-    :rtype: set[str]
     """
     return graph.defined_namespace_keywords - get_namespaces(graph)
 
 
-def get_names(graph):
+def get_names(graph) -> Mapping[str, Set[str]]:
     """Get all names for each namespace.
 
     :type graph: pybel.BELGraph
@@ -109,7 +104,7 @@ def get_names(graph):
     return dict(rv)
 
 
-def _identifier_filtered_iterator(graph):
+def _identifier_filtered_iterator(graph) -> Iterable[Tuple[str, str]]:
     """Iterate over names in the given namespace."""
     for data in graph:
         for pair in _get_node_names(data):
@@ -144,35 +139,36 @@ def _identifier_filtered_iterator(graph):
             yield location[NAMESPACE], location[NAME]
 
 
-def _get_node_names(data):
-    if NAMESPACE in data:
-        yield data[NAMESPACE], data[NAME]
+def _get_node_names(data: Mapping[str, Any]) -> Iterable[Tuple[str, str]]:
+    if CONCEPT in data:
+        yield data[CONCEPT][NAMESPACE], data[CONCEPT][NAME]
 
     elif FUSION in data:
-        yield data[FUSION][PARTNER_3P][NAMESPACE], data[FUSION][PARTNER_3P][NAME]
-        yield data[FUSION][PARTNER_5P][NAMESPACE], data[FUSION][PARTNER_5P][NAME]
+        partner_5p_concept = data[FUSION][PARTNER_5P][CONCEPT]
+        partner_3p_concept = data[FUSION][PARTNER_3P][CONCEPT]
+        yield partner_5p_concept[NAMESPACE], partner_5p_concept[NAME]
+        yield partner_3p_concept[NAMESPACE], partner_3p_concept[NAME]
 
     if VARIANTS in data:
         for variant in data[VARIANTS]:
-            identifier = variant.get(IDENTIFIER)
-            if identifier is not None and NAMESPACE in identifier and NAME in identifier:
-                yield identifier[NAMESPACE], identifier[NAME]
+            concept = variant.get(CONCEPT)
+            if concept is not None and NAMESPACE in concept and NAME in concept:
+                yield concept[NAMESPACE], concept[NAME]
 
 
-def _namespace_filtered_iterator(graph, namespace):
+def _namespace_filtered_iterator(graph, namespace: str) -> Iterable[str]:
     """Iterate over names in the given namespace."""
     for it_namespace, name in _identifier_filtered_iterator(graph):
         if namespace == it_namespace:
             yield name
 
 
-def count_names_by_namespace(graph, namespace):
+def count_names_by_namespace(graph, namespace: str) -> typing.Counter[str]:
     """Get the set of all of the names in a given namespace that are in the graph.
 
     :param pybel.BELGraph graph: A BEL graph
-    :param str namespace: A namespace keyword
+    :param namespace: A namespace keyword
     :return: A counter from {name: frequency}
-    :rtype: collections.Counter
 
     :raises IndexError: if the namespace is not defined in the graph.
     """
@@ -182,13 +178,12 @@ def count_names_by_namespace(graph, namespace):
     return Counter(_namespace_filtered_iterator(graph, namespace))
 
 
-def get_names_by_namespace(graph, namespace):
+def get_names_by_namespace(graph, namespace: str) -> Set[str]:
     """Get the set of all of the names in a given namespace that are in the graph.
 
     :param pybel.BELGraph graph: A BEL graph
-    :param str namespace: A namespace keyword
+    :param namespace: A namespace keyword
     :return: A set of names belonging to the given namespace that are in the given graph
-    :rtype: set[str]
 
     :raises IndexError: if the namespace is not defined in the graph.
     """
@@ -198,11 +193,10 @@ def get_names_by_namespace(graph, namespace):
     return set(_namespace_filtered_iterator(graph, namespace))
 
 
-def count_variants(graph):
+def count_variants(graph) -> typing.Counter[str]:
     """Count how many of each type of variant a graph has.
 
     :param pybel.BELGraph graph: A BEL graph
-    :rtype: Counter
     """
     return Counter(
         variant_data[KIND]
@@ -212,41 +206,33 @@ def count_variants(graph):
     )
 
 
-def get_top_hubs(graph, count=15):
+def get_top_hubs(graph, *, n: Optional[int] = 15) -> List[Tuple[BaseEntity, int]]:
     """Get the top hubs in the graph by BEL.
 
     :param pybel.BELGraph graph: A BEL graph
-    :param Optional[int] count: The number of top hubs to return. If None, returns all nodes
-    :rtype: dict[tuple,int]
+    :param n: The number of top hubs to return. If None, returns all nodes
     """
-    return Counter(dict(graph.degree())).most_common(count)
+    return Counter(dict(graph.degree())).most_common(n=n)
 
 
-def _pathology_iterator(graph):
-    """Iterate over edges in which either the source or target is a pathology node.
-
-    :param pybel.BELGraph graph: A BEL graph
-    :rtype: iter
-    """
-    for node in itt.chain.from_iterable(graph.edges()):
-        if isinstance(node, Pathology):
-            yield node
-
-
-def count_pathologies(graph):
+def count_pathologies(graph) -> typing.Counter[BaseEntity]:
     """Count the number of edges in which each pathology is incident.
 
     :param pybel.BELGraph graph: A BEL graph
-    :rtype: Counter
     """
-    return Counter(_pathology_iterator(graph))
+    # Don't double count relationships
+    edges = {tuple(sorted([u, v], key=lambda node: node.as_bel())) for u, v in graph.edges()}
+    return Counter(
+        node
+        for node in itt.chain.from_iterable(edges)
+        if isinstance(node, Pathology)
+    )
 
 
-def get_top_pathologies(graph, count=15):
+def get_top_pathologies(graph, n: Optional[int] = 15) -> List[Tuple[BaseEntity, int]]:
     """Get the top highest relationship-having edges in the graph by BEL.
 
     :param pybel.BELGraph graph: A BEL graph
-    :param Optional[int] count:
-    :rtype: dict[tuple,int]
+    :param n: The number of top connected pathologies to return. If None, returns all nodes
     """
-    return count_pathologies(graph).most_common(count)
+    return count_pathologies(graph).most_common(n)
